/*
 * Created on 23-nov-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.play.models;

import java.io.File;
import java.io.OutputStream;
import java.util.List;

import javax.sound.midi.Soundbank;
import javax.sound.midi.Synthesizer;

import org.herac.tuxguitar.song.models.SongChannel;
import org.herac.tuxguitar.song.models.SongTrack;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public interface Player {
    public void init();
    public void close();
    public void play();
    public void pause();
    public void stop();    
    public void reset();
    public boolean isPaused();
    public boolean isRunning();
    public void setSynthesizer(Synthesizer synthesizer);
    public void playBeat(final SongTrack track,final List notes);
    public void updateChannels();
    public void updateChannel(SongChannel channel);
    public void setTickPosition(long position,long startMove);
    public long getTickPosition();
    public Soundbank getSoundbank();
    public boolean loadSoundbank(File file);
    public void write(OutputStream out);
}
